**********
sandplover
**********

.. image:: https://github.com/sandpiper-toolchain/sandplover/actions/workflows/build.yml/badge.svg?branch=develop
  :target: https://github.com/sandpiper-toolchain/sandplover/actions

.. image:: https://codecov.io/gh/sandpiper-toolchain/sandplover/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/sandpiper-toolchain/sandplover

*sandplover* is a Python package for manipulating depositional system data cubes.
The package has robust objects and routines designed to help organize, visualize, and analyze topography and sedimentological timeseries data.
*sandplover* works especially well with data from deltaic systems (e.g., the `pyDeltaRCM numerical model <https://github.com/DeltaRCM/pyDeltaRCM>`_  and laboratory delta experiments).
This software was previously known as *DeltaMetrics*.

`Full documentation here <https://sandpiper-toolchain.github.io/sandplover/index.html>`_.


.. figure:: https://sandpiper-toolchain.github.io/sandplover/_images/cover.png

  A view of bed elevation on a modeled deltaic deposit in ``Planform``, and a cross ``StrikeSection`` view of the timing of sediment deposition in stratigraphy.
